@@ -5,7 +5,7 @@ use strict;
 use lib 'lib';
 use WebService::eBay;
 
-my $response = eBay::APICall("GeteBayOfficialTime");
+my $response = WebService::eBay::APICall("GeteBayOfficialTime");
 print "$response->{Timestamp}\n";
 
 my $listingNumber = '142306955';
